"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processLanguages = exports.processTranslations = void 0;
const i18n_module_1 = require("../i18n.module");
const merge_1 = require("./merge");
async function processTranslations(loaders) {
    try {
        const loadedTranslations = await Promise.all(loaders.map((loader) => loader.load()));
        return loadedTranslations
            .filter((translation) => translation !== undefined)
            .reduce((acc, translation) => {
            return (0, merge_1.mergeTranslations)(acc, translation);
        }, {});
    }
    catch (e) {
        i18n_module_1.logger.error('parsing translations files or processing error', e);
        throw e;
    }
}
exports.processTranslations = processTranslations;
async function processLanguages(loaders) {
    try {
        const allLanguages = await Promise.all(loaders.map((loader) => loader.languages()));
        const languagesToRespond = allLanguages
            .filter((languages) => languages !== undefined)
            .flatMap((languages) => languages);
        return [...new Set(languagesToRespond)];
    }
    catch (e) {
        i18n_module_1.logger.error('parsing languages or processing error', e);
        throw e;
    }
}
exports.processLanguages = processLanguages;
//# sourceMappingURL=loaders-utils.js.map